const simpleGit = require('simple-git');
const fs = require('fs/promises');
const path = require('path');

class CommentManager {
  constructor(projectPath) {
    this.projectPath = projectPath;
    this.git = simpleGit(projectPath);
  }

  async backupAndRemoveComments(filePath) {
    try {
      // Create backup branch
      const branchName = `${path.basename(filePath)}_copy_${Date.now()}`;
      await this.createBackupBranch(branchName);

      // Read file content
      const content = await fs.readFile(filePath, 'utf8');

      // Remove comments and extra spaces
      const cleanedContent = this.removeComments(content);

      // Write back cleaned content
      await fs.writeFile(filePath, cleanedContent);

      return {
        success: true,
        backupBranch: branchName,
        message: `Comments backed up to branch ${branchName} and removed from working copy`
      };
    } catch (error) {
      return {
        success: false,
        error: error.message
      };
    }
  }

  async createBackupBranch(branchName) {
    await this.git.checkoutLocalBranch(branchName);
    await this.git.add('.');
    await this.git.commit('Backup before removing comments');
    await this.git.checkout('main'); // Or whatever the original branch was
  }

  removeComments(content) {
    // Remove single-line comments
    content = content.replace(/\/\/.*$/gm, '');
    
    // Remove multi-line comments
    content = content.replace(/\/\*[\s\S]*?\*\//g, '');
    
    // Remove extra blank lines
    content = content.replace(/^\s*[\r\n]/gm, '');
    
    // Remove extra spaces
    content = content.replace(/[ \t]+/g, ' ').trim();
    
    return content;
  }
}

module.exports = CommentManager;