class PerformanceMonitor {
  constructor() {
    this.measurements = new Map();
    this.startTimes = new Map();
  }

  startMeasure(componentName) {
    this.startTimes.set(componentName, performance.now());
  }

  endMeasure(componentName) {
    const startTime = this.startTimes.get(componentName);
    if (startTime) {
      const duration = performance.now() - startTime;
      if (!this.measurements.has(componentName)) {
        this.measurements.set(componentName, []);
      }
      this.measurements.get(componentName).push(duration);
      this.startTimes.delete(componentName);
    }
  }

  getMetrics() {
    const metrics = {};
    this.measurements.forEach((durations, componentName) => {
      metrics[componentName] = {
        averageRenderTime: this.calculateAverage(durations),
        maxRenderTime: Math.max(...durations),
        minRenderTime: Math.min(...durations),
        renderCount: durations.length
      };
    });
    return metrics;
  }

  calculateAverage(numbers) {
    return numbers.reduce((a, b) => a + b, 0) / numbers.length;
  }

  identifyBottlenecks(threshold = 16) {
    const bottlenecks = [];
    this.measurements.forEach((durations, componentName) => {
      const slowRenders = durations.filter(duration => duration > threshold);
      if (slowRenders.length > 0) {
        bottlenecks.push({
          component: componentName,
          slowRenderCount: slowRenders.length,
          averageSlowRenderTime: this.calculateAverage(slowRenders)
        });
      }
    });
    return bottlenecks;
  }
}

module.exports = PerformanceMonitor;