import React from "react";
const React = require('react');

class RenderDetector {
  constructor() {
    this.renderCounts = new Map();
    this.renderTriggers = new Map();
  }

  track(ComponentToTrack) {
    return class RenderTracker extends React.Component {
      componentDidUpdate(prevProps) {
        const changes = this.detectPropChanges(prevProps, this.props);
        this.updateRenderTriggers(changes);
      }

      detectPropChanges(prevProps, currentProps) {
        return Object.keys(currentProps).filter(
          key => prevProps[key] !== currentProps[key]
        );
      }

      updateRenderTriggers(changes) {
        const componentName = ComponentToTrack.name;
        if (!this.renderTriggers.has(componentName)) {
          this.renderTriggers.set(componentName, new Map());
        }
        changes.forEach(prop => {
          const triggers = this.renderTriggers.get(componentName);
          triggers.set(prop, (triggers.get(prop) || 0) + 1);
        });
      }

      render() {
        const componentName = ComponentToTrack.name;
        this.renderCounts.set(
          componentName,
          (this.renderCounts.get(componentName) || 0) + 1
        );
        return <ComponentToTrack {...this.props} />;
      }
    };
  }

  getReport() {
    return {
      renderCounts: Object.fromEntries(this.renderCounts),
      renderTriggers: Object.fromEntries(
        Array.from(this.renderTriggers.entries()).map(([component, triggers]) => [
          component,
          Object.fromEntries(triggers)
        ])
      )
    };
  }
}

module.exports = RenderDetector;
